aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_exchange_service.h
diff options
context:
space:
mode:
authorÖzgür Kesim <oec-taler@kesim.org>2023-07-16 13:33:08 +0200
committerÖzgür Kesim <oec-taler@kesim.org>2023-07-16 13:33:08 +0200
commit77f99b636357c7e0fbf20a2965c1fbe9c3e86f5e (patch)
tree3e304bdce4d78f1bd3122931be2cb4da33dc205d /src/include/taler_exchange_service.h
parent3ce29a711bf1832c6ce8425d20d262d36a7d83ad (diff)
downloadexchange-77f99b636357c7e0fbf20a2965c1fbe9c3e86f5e.tar.xz
-doxygen fixes
Diffstat (limited to 'src/include/taler_exchange_service.h')
-rw-r--r--src/include/taler_exchange_service.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 62b273e1b..b20689af4 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -2993,9 +2993,8 @@ typedef void
*
* @param curl_ctx The curl context
* @param exchange_url The base url of the exchange
- * @param reserve_priv The pivate key to the reserve
* @param num_coins The number of elements in @e coin_inputs and @e alg_values
* @param coins_input The input for the coins to withdraw, same as in the previous call to /age-withdraw
* @param alg_values The algorithm specific parameters per coin, from the result to the previous call to /age-withdraw
* @param noreveal_index The index into each of the kappa coin candidates, that should not be revealed to the exchange
* @param h_commitment The commmitment from the previous call to /age-withdraw
@@ -3010,7 +3009,7 @@ TALER_EXCHANGE_age_withdraw_reveal (
struct GNUNET_CURL_Context *curl_ctx,
const char *exchange_url,
size_t num_coins,
- const struct TALER_EXCHANGE_AgeWithdrawCoinInput coins_input[static
+ const struct TALER_EXCHANGE_AgeWithdrawCoinInput coin_inputs[static
num_coins],
const struct TALER_ExchangeWithdrawValues alg_values[static num_coins],
uint8_t noreveal_index,
@@ -2993,9 +2993,8 @@ typedef void
* @param num_coins The number of elements in @e coin_inputs and @e alg_values
- * @param coins_input The input for the coins to withdraw, same as in the previous call to /age-withdraw
+ * @param coin_inputs The input for the coins to withdraw, same as in the previous call to /age-withdraw
* @param alg_values The algorithm specific parameters per coin, from the result to the previous call to /age-withdraw
* @param noreveal_index The index into each of the kappa coin candidates, that should not be revealed to the exchange